@@ -1446,12 +1446,15 @@ function formatBytesJS(bytes, precision = 2) {
     }
     
     const units = ['B', 'KB', 'MB', 'GB', 'TB'];
+    let unitIndex = 0;
     
-    for (let i = 0; bytes > 1024 && i < units.length - 1; i++) {
+    // Convert bytes to appropriate unit
+    while (bytes >= 1024 && unitIndex < units.length - 1) {
         bytes /= 1024;
+        unitIndex++;
     }
     
-    return bytes.toFixed(precision) + ' ' + units[Math.max(0, Math.min(units.length - 1, Math.floor(Math.log(bytes) / Math.log(1024))))];
+    return bytes.toFixed(precision) + ' ' + units[unitIndex];
 }
 
 // Search on enter key
@@ -1527,13 +1530,19 @@ document.getElementById('targetGlobal').addEventListener('change', function() {
 
 <?php
 function formatBytes($bytes, $precision = 2) {
-    $units = array('B', 'KB', 'MB', 'GB', 'TB');
-    
-    for ($i = 0; $bytes > 1024 && $i < count($units) - 1; $i++) {
-        $bytes /= 1024;
+    if ($bytes <= 0) {
+        return '0 B';
     }
     
-    return round($bytes, $precision) . ' ' . $units[$i];
+    $units = array('B', 'KB', 'MB', 'GB', 'TB');
+    $unitIndex = 0;
+    
+    while ($bytes >= 1024 && $unitIndex < count($units) - 1) {
+        $bytes /= 1024;
+        $unitIndex++;
+    }
+    
+    return round($bytes, $precision) . ' ' . $units[$unitIndex];
 }
 
 function getBackupTypeColor($type) {
